@@ -241,13 +241,7 @@ class OauthCommand(Command):
         self.shell.msg("     oauth_token: %s" % self.shell.options['token'][0])
         self.shell.msg("     oauth_token_secret: %s" % self.shell.options['token'][1])
         self.shell.msg('')
-
-        save = self.shell.prompt('Save token to file? [Y/n]')
-        if save.lower.startswith('y') or save == '':
-            where = self.shell.prompt('Where would you like to save this file? [.freelancer.token]')
-            if not where:
-                where = '.freelancer.token'
-            self.save(**{'file': where})
+        self.shell.msg('To save this token for use with oauth.load(), save it with oauth.save()')
 
         return self.shell
 
